#!/usr/local/bin/php
<?php
/**
 * $Horde: whups/scripts/mail-filter.php,v 1.11 2005/01/12 17:04:45 chuck Exp $
 *
 * This script accepts a MIME message on standard input and creates a
 * new ticket from its contents.
 */

@define('AUTH_HANDLER', true);
@define('HORDE_BASE', dirname(__FILE__) . '/../..');

// Do CLI checks and environment setup first.
require_once HORDE_BASE . '/lib/core.php';
require_once 'Horde/CLI.php';

// Make sure no one runs this from the web.
if (!Horde_CLI::runningFromCLI()) {
    exit("Must be run from the command line\n");
}

// Load the CLI environment - make sure there's no time limit, init
// some variables, etc.
Horde_CLI::init();
$cli = &Horde_CLI::singleton();

@define('WHUPS_BASE', HORDE_BASE . '/whups');
require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Mail.php';
require_once WHUPS_BASE . '/lib/Ticket.php';
require_once 'Console/Getopt.php';

// We accept the user name on the command-line.
$options = Console_Getopt::getopt(Console_Getopt::readPHPArgv(), 'q:t:p:S:',
                                  array('queue=', 'type=', 'priority=', 'state='));

if (is_a($options, 'PEAR_Error')) {
    // FIXME: We should bounce the message.
    exit(1);
}

list($opts, $args) = $options;
foreach ($opts as $opt) {
    list($optName, $optValue) = $opt;
    switch ($optName) {
    case 'q':
    case '--queue':
        $optQueue = $optValue;
        break;

    case 't':
    case '--type':
        $optType = $optValue;
        break;

    case 'p':
    case '--priority':
        $optPriority = $optValue;
        break;

    case 's':
    case '--state':
        $optState = $optValue;
        break;
    }
}

$info = array();

if (empty($optQueue)) {
    $cli->fatal(_("--queue option must be supplied."));
}
$queues = $whups->getQueues();
foreach ($queues as $queueId => $queueName) {
    if (strcasecmp($queueName, $optQueue) == 0) {
        $info['queue'] = $queueId;
        break;
    }
}
if (!isset($info['queue'])) {
    $cli->fatal(sprintf(_("Queue `%s' does not exist."), $optQueue));
}

if (empty($optType)) {
    $cli->fatal(_("--type option must be supplied."));
}
$types = $whups->getTypes($info['queue']);
foreach ($types as $typeId => $typeName) {
    if (strcasecmp($typeName, $optType) == 0) {
        $info['type'] = $typeId;
        break;
    }
}
if (!isset($info['type'])) {
    $cli->fatal(sprintf(_("Bad type `%s' for queue."), $optType));
}

if (empty($optPriority)) {
    $cli->fatal(_("--priority option must be supplied."));
}
$priorities = $whups->getPriorities($info['type']);
foreach ($priorities as $priorityId => $priorityName) {
    if (strcasecmp($priorityName, $optPriority) == 0) {
        $info['priority'] = $priorityId;
        break;
    }
}
if (!isset($info['priority'])) {
    $cli->fatal(sprintf(_("bad priority `%s' for type."), $optPriority));
}

if (empty($optState)) {
    $cli->fatal(_("--state option must be supplied."));
}
$states = $whups->getStates($info['type']);
foreach ($states as $stateId => $stateName) {
    if (strcasecmp($stateName, $optState) == 0) {
        $info['state'] = $stateId;
        break;
    }
}
if (!isset($info['state'])) {
    $cli->fatal(sprintf(_("bad state `%s' for type."), $optState));
}

// Read and parse the message.
$text = '';
while (!feof(STDIN)) {
    $text .= fgets(STDIN, 512);
}

$result = Whups_Mail::processMail($text, $info);
if (is_a($result, 'PEAR_Error')) {
    $cli->fatal(sprintf(_("error processing message: %s"), $result->getMessage()));
    exit(1);
}

exit(0);
